==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_functions/mp7863_001/MP7863_GetCustomerRentalAdjustment_001.java <==

package net.datastream.schemas.mp_functions.mp7863_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CUSTOMERRENTALADJUSTMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALADJUSTMENTID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="CustomerRentalAdjustment" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerrentaladjustmentid"
})
@XmlRootElement(name = "MP7863_GetCustomerRentalAdjustment_001")
public class MP7863_GetCustomerRentalAdjustment_001 {

    @XmlElement(name = "CUSTOMERRENTALADJUSTMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERRENTALADJUSTMENTID_Type customerrentaladjustmentid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the customerrentaladjustmentid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERRENTALADJUSTMENTID_Type }
     *     
     */
    public CUSTOMERRENTALADJUSTMENTID_Type getCUSTOMERRENTALADJUSTMENTID() {
        return customerrentaladjustmentid;
    }

    /**
     * Sets the value of the customerrentaladjustmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERRENTALADJUSTMENTID_Type }
     *     
     */
    public void setCUSTOMERRENTALADJUSTMENTID(CUSTOMERRENTALADJUSTMENTID_Type value) {
        this.customerrentaladjustmentid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.CUSTOMER_RENTAL_ADJUSTMENT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp7863_001/MP7863_GetCustomerRentalAdjustment_001.java <==

package net.datastream.schemas.mp_functions.mp7863_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CUSTOMERRENTALADJUSTMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALADJUSTMENTID"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="CustomerRentalAdjustment" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerrentaladjustmentid"
})
@XmlRootElement(name = "MP7863_GetCustomerRentalAdjustment_001")
public class MP7863_GetCustomerRentalAdjustment_001 {

    @XmlElement(name = "CUSTOMERRENTALADJUSTMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERRENTALADJUSTMENTID_Type customerrentaladjustmentid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the customerrentaladjustmentid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERRENTALADJUSTMENTID_Type }
     *     
     */
    public CUSTOMERRENTALADJUSTMENTID_Type getCUSTOMERRENTALADJUSTMENTID() {
        return customerrentaladjustmentid;
    }

    /**
     * Sets the value of the customerrentaladjustmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERRENTALADJUSTMENTID_Type }
     *     
     */
    public void setCUSTOMERRENTALADJUSTMENTID(CUSTOMERRENTALADJUSTMENTID_Type value) {
        this.customerrentaladjustmentid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.CUSTOMER_RENTAL_ADJUSTMENT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
